Module: Searchy
Instance Method Summary collapse
- #clean(&block) ⇒ Object
- #fix(list) ⇒ Object
- #hash_url(url) ⇒ Object
- #maxhits=(value) ⇒ Object
-
#print_emails(list) ⇒ Object
HELPER METHODS ———————————————————————————.
- #search_depth ⇒ Object
- #search_docs(urls) ⇒ Object
- #search_emails(string) ⇒ Object
- #search_office_xml(urls) ⇒ Object
- #search_pdfs(urls) ⇒ Object
- #search_txts(urls) ⇒ Object
Instance Method Details
#clean(&block) ⇒ Object
267 268 269 |
# File 'lib/esearchy/searchy.rb', line 267 def clean( &block ) @emails.delete_if &block.call end |
#fix(list) ⇒ Object
259 260 261 262 263 264 265 |
# File 'lib/esearchy/searchy.rb', line 259 def fix(list) list.each do |e| e.gsub!(" at ","@") e.gsub!("_at_","@") e.gsub!(" dot ",".") end end |
#hash_url(url) ⇒ Object
255 256 257 |
# File 'lib/esearchy/searchy.rb', line 255 def hash_url(url) Digest::SHA2.hexdigest("#{Time.now.to_f}--#{url}") end |
#maxhits=(value) ⇒ Object
271 272 273 |
# File 'lib/esearchy/searchy.rb', line 271 def maxhits=( value ) @totalhits = value end |
#print_emails(list) ⇒ Object
HELPER METHODS ———————————————————————————
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/esearchy/searchy.rb', line 231 def print_emails(list) list.each do |email| unless @emails.include?(email) unless RUBY_PLATFORM =~ /mingw|mswin/ if email.match(/#{@query.gsub("@","").split('.')[0]}/) ESearchy::LOG.puts "\033[31m" + email + "\033\[0m" else ESearchy::LOG.puts "\033[32m" + email + "\033\[0m" end else if email.match(/#{@query.gsub("@","").split('.')[0]}/) Wcol::color(12) ESearchy::LOG.puts email Wcol::color(7) else Wcol::color(2) ESearchy::LOG.puts email Wcol::color(7) end end end end end |
#search_depth ⇒ Object
275 276 277 278 279 280 281 282 |
# File 'lib/esearchy/searchy.rb', line 275 def search_depth search_pdfs @r_pdfs if @r_pdfs search_txts @r_txts if @r_txts search_office_xml @r_officexs if @r_officexs if RUBY_PLATFORM =~ /mingw|mswin/ search_docs @r_docs if @r_docs end end |
#search_docs(urls) ⇒ Object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/esearchy/searchy.rb', line 88 def search_docs(urls) while urls.size >= 1 @threads << Thread.new do web = URI.parse(urls.pop) ESearchy::LOG.puts "Searching in DOC: #{web.to_s}\n" begin http = Net::HTTP.new(web.host,80) http.start do |http| request = Net::HTTP::Get.new("#{web.path}#{web.query}") response = http.request(request) case response when Net::HTTPSuccess, Net::HTTPRedirection name = Searchy::TEMP + "#{hash_url(web.to_s)}.doc" open(name, "wb") do |file| file.write(response.body) end if RUBY_PLATFORM =~ /mingw|mswin/ begin word = WIN32OLE.new('word.application') word.documents.open(name) word.selection.wholestory search_emails(word.selection.text.chomp) word.activedocument.close( false ) word.quit rescue if File.exists?("C:\\antiword\\antiword.exe") search_emails(`C:\\antiword\\antiword.exe "#{name}" -f -s`) else # This G h e t t o but, for now it works on emails # that do not contain Capital letters:) ESearchy::LOG.puts "M$ Word|Antiword are not installed. Using the Ghetto way." search_emails( File.open(name).readlines[0..19].to_s ) end end elsif RUBY_PLATFORM =~ /linux|darwin/ begin if File.exists?("/usr/bin/antiword") or File.exists?("/usr/local/bin/antiword") or File.exists?("/opt/local/bin/antiword") search_emails(`antiword "#{name}" -f -s`) else # This G h e t t o but, for now it works on emails # that do not contain Capital letters:) ESearchy::LOG.puts "Antiword is not installed. Using the Ghetto way." search_emails( File.open(name).readlines[0..19].to_s ) end rescue ESearchy::LOG.puts "Something went wrong parsing the .doc\n" end else ESearchy::LOG.puts "This platform is not currently supported." end `rm "#{name}"` else return response.error! end end rescue Net::HTTPFatalError ESearchy::LOG.puts "Error: Something went wrong with the HTTP request.\n" rescue Net::HTTPServerException ESearchy::LOG.puts "Error: Not longer there. 404 Not Found.\n" rescue ESearchy::LOG.puts "Error: < .. SocketError .. >\n" end end end @threads.each {|t| t.join } if @threads != nil end |
#search_emails(string) ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/esearchy/searchy.rb', line 20 def search_emails(string) string = string.gsub("<em>","") if self.class == Google # OLD regex list = string.scan(/[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*@ # (?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/) # list = string.scan(/[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*_at_ #(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?| #[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*\sat\s(?:[a-z0-9](?:[a-z0-9-] #*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|[a-z0-9!#$&'*+=?^_`{|}~-]+ #(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?| #[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*\s@\s(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+ #[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\sdot\s[a-z0-9!#$&'*+=?\^_` #{|}~-]+)*\sat\s(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\sdot\s)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/) list = string.scan(/[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*_at_\ (?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z](?:[a-z-]*[a-z])?|\ [a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*\sat\s(?:[a-z0-9](?:[a-z0-9-]\ *[a-z0-9])?\.)+[a-z](?:[a-z-]*[a-z])?|[a-z0-9!#$&'*+=?^_`{|}~-]+\ (?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z](?:[a-z-]*[a-z])?|\ [a-z0-9!#$&'*+=?^_`{|}~-]+(?:\.[a-z0-9!#$&'*+=?\^_`{|}~-]+)*\s@\s(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+\ [a-z](?:[a-z-]*[a-z])?|[a-z0-9!#$&'*+=?^_`{|}~-]+(?:\sdot\s[a-z0-9!#$&'*+=?\^_`\ {|}~-]+)*\sat\s(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\sdot\s)+[a-z](?:[a-z-]*[a-z])??/) @lock.synchronize do print_emails(list) @emails.concat(fix(list)).uniq! end end |
#search_office_xml(urls) ⇒ Object
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/esearchy/searchy.rb', line 157 def search_office_xml(urls) while urls.size >= 1 @threads << Thread.new do web = URI.parse(urls.pop) #format = web.scan(/docx|xlsx|pptx/i)[0] format = web.scan(/docx|xlsx|pptx|odt|odp|ods|odb/i)[0] ESearchy::LOG.puts "Searching in #{format.upcase}: #{web.to_s}\n" begin http = Net::HTTP.new(web.host,80) http.start do |http| request = Net::HTTP::Get.new("#{web.path}#{web.query}") response = http.request(request) case response when Net::HTTPSuccess, Net::HTTPRedirection name = Searchy::TEMP + "#{hash_url(web.to_s)}." + format open(name, "wb") do |file| file.write(response.body) end begin Zip::ZipFile.open(name) do |zip| text = z.entries.each { |e| zip.file.read(e.name) if e.name =~ /.xml$/} search_emails(text) end rescue ESearchy::LOG.puts "Something went wrong parsing the .#{format.downcase}\n" end `rm "#{name}"` else return response.error! end end rescue Net::HTTPFatalError ESearchy::LOG.puts "Error: Something went wrong with the HTTP request.\n" rescue Net::HTTPServerException ESearchy::LOG.puts "Error: Not longer there. 404 Not Found.\n" rescue ESearchy::LOG.puts "Error: < .. SocketError .. >\n" end end end @threads.each {|t| t.join } if @threads != nil end |
#search_pdfs(urls) ⇒ Object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/esearchy/searchy.rb', line 46 def search_pdfs(urls) while urls.size >= 1 @threads << Thread.new do web = URI.parse(urls.pop) ESearchy::LOG.puts "Searching in PDF: #{web.to_s}\n" begin http = Net::HTTP.new(web.host,80) http.start do |http| request = Net::HTTP::Get.new("#{web.path}#{web.query}") response = http.request(request) case response when Net::HTTPSuccess, Net::HTTPRedirection name = Searchy::TEMP + "#{hash_url(web.to_s)}.pdf" open(name, "wb") do |file| file.write(response.body) end begin receiver = PageTextReceiver.new pdf = PDF::Reader.file(name, receiver) search_emails(receiver.content.inspect) rescue PDF::Reader::UnsupportedFeatureError ESearchy::LOG.puts "Encrypted PDF: Unable to parse it.\n" rescue PDF::Reader::MalformedPDFError ESearchy::LOG.puts "Malformed PDF: Unable to parse it.\n" end `rm "#{name}"` else return response.error! end end rescue Net::HTTPFatalError ESearchy::LOG.puts "Error: Something went wrong with the HTTP request.\n" rescue Net::HTTPServerException ESearchy::LOG.puts "Error: Not longer there. 404 Not Found.\n" rescue ESearchy::LOG.puts "Error: < .. SocketError .. >\n" end end end @threads.each {|t| t.join } if @threads != nil end |
#search_txts(urls) ⇒ Object
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/esearchy/searchy.rb', line 200 def search_txts(urls) while urls.size >= 1 @threads << Thread.new do web = URI.parse(urls.pop) ESearchy::LOG.puts "Searching in #{web.to_s.scan(/txt|rtf|ans/i)[0].upcase}: #{web.to_s}\n" begin http = Net::HTTP.new(web.host,80) http.start do |http| request = Net::HTTP::Get.new("#{web.path}#{web.query}") response = http.request(request) case response when Net::HTTPSuccess, Net::HTTPRedirection search_emails(response.body) else return response.error! end end rescue Net::HTTPFatalError ESearchy::LOG.puts "Error: Something went wrong with the HTTP request\n" rescue Net::HTTPServerException ESearchy::LOG.puts "Error: Not longer there. 404 Not Found.\n" rescue ESearchy::LOG.puts "Error: < .... >" end end end @threads.each {|t| t.join } if @threads != nil end |